# ListStandaloneRulesetLabelsResponse

Response object for StandaloneRulesetLabel list

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**standalone_ruleset_labels** | [**[StandaloneRulesetLabel]**](StandaloneRulesetLabel.md) | List of StandaloneRulesetLabel | 
**limit** | **int** | Limit on the number of rows in the response | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


